#
# spec file for package xfburn
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xfburn
Version:        0.7.2
Release:        1.6
Summary:        Simple CD/DVD Burning Application
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/CD/Record
URL:            https://docs.xfce.org/apps/xfburn/start
Source:         https://archive.xfce.org/src/apps/xfburn/0.7/%{name}-%{version}.tar.bz2
BuildRequires:  appstream-glib
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(exo-2) >= 0.11.0
BuildRequires:  pkgconfig(gio-2.0) >= 2.38
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-pbutils-1.0)
BuildRequires:  pkgconfig(gthread-2.0) >= 2.38
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.20
BuildRequires:  pkgconfig(gudev-1.0)
BuildRequires:  pkgconfig(libburn-1) >= 0.4.2
BuildRequires:  pkgconfig(libisofs-1) >= 0.6.2
BuildRequires:  pkgconfig(libxfce4ui-2) >= 4.12.0
Recommends:     %{name}-lang = %{version}

%description
Xfburn is a simple CD/DVD burning application based on the libburnia libraries.
It can blank CD-RWs, burn and create iso images, as well as burn personal
compositions of data to either CD or DVD.

%lang_package

%prep
%autosetup

%build
%configure
%make_build

%install
%make_install

%find_lang %{name} %{?no_lang_C}

appstream-util validate-relax --nonet %{buildroot}%{_datadir}/metainfo/*.appdata.xml

%files
%license COPYING
%doc README.md AUTHORS NEWS TODO
%{_bindir}/xfburn
%{_datadir}/applications/xfburn.desktop
%{_mandir}/man1/xfburn.1%{?ext_man}
%{_datadir}/xfburn
%{_datadir}/icons/hicolor/*/*/*/*xfburn*
%dir %{_datadir}/Thunar
%dir %{_datadir}/Thunar/sendto
%{_datadir}/Thunar/sendto/thunar-sendto-xfburn.desktop
%{_datadir}/metainfo/*.appdata.xml

%files lang -f %{name}.lang

%changelog
* Tue Aug 13 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.7.2
  * Fix help dialog opening on unintended keypresses
* Mon Jul 15 2024 Maurizio Galli <maurizio.galli@suse.com>
- Update to version 0.7.1
  * build: clang: Silence -Wcast-align
  * build: clang: Fix -Wmissing-noreturn
  * build: clang: Fix -Wuninitialized
  * build: clang: Fix -Wunused-but-set-variable
  * Simulate F1 accelerator for Help
  * Add Contents entry to Help menu
  * build: Fix autoconf warning
  * Add missing end tag to ui file
  * I18n: Update po/LINGUAS list
  * build: Use XDT_VERSION_INIT and get rid of configure.ac.in
  * build: Switch from intltool to gettext
  * Fix bashism in configure test
  * Add missing G_END_DECLS
  * Remove roles from about dialog
  * Update copyright information
  * Look for toast and img extensions, not just iso
  * Fix segfault when settings file is readonly
  * Update README.md
  * Translation Updates
* Sat Mar  4 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.7.0
  * Add MIME types to open blank and audio CDs
  * Automatically update burner list as burners are plugged and unplugged
  * Change default temporary directory to /var/tmp
  * Improve text of write modes
  * Replace some icons with symbolic versions that better respect light/dark mode
  * Support delete key in audio compositions
  * Fix adding progress dialog not appearing after dragging files
  * Fix adding progress dialog cancel button not working
  * Fix adding progress dialog not being modal
  * Fix assertion failure when burner not present
  * Fix composition term not being used consistently
  * Fix crash when adding files to a data composition
  * Fix dragged audio composition tracks being copied instead of moved
  * Fix excessive minimum width of main window
  * Fix icons not appearing on dialogs
  * Fix intltool lock file bug in `make distcheck`
  * Fix multiple selection being instantly deselected upon right click
  * Fix multithreading issue when initializing an audio composition
  * Fix out-of-date address in COPYING
  * Fix project homepage URL
  * Fix removed audio composition tracks not reducing total composition length
  * Fix some compilation warnings
  * Fix typo in burn failure dialog
  * Fix XSLT processor warnings
  * Add basic GitLab pipeline
  * Add Markdown version of the README
  * Add more translatable content to the AppStream/AppData
  * Bump GLib minimum required to 2.38
  * Modernize build system
  * Resolve AppStream warnings from Debian
  * Strip trailing whitespace like as in Debian's build process
  * Update bug tracker links in readme
  * Update information on how to build xfburn
  * Translation Updates
* Thu Jan  7 2021 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed URL
* Sun Mar  8 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 0.6.2
  * Displaying device revision information in the device dialog
  * Made popup context menu translatable
  * Code clean up for deprecated Glib/Gtk+ Widget definitions
  * updated AppData to AppStream and project URLs all around
  * Made xfburn.ui translatable
  * minor cleanups
  * Translation Updates
* Tue Nov  5 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 0.6.1
  - fixed website link in the about dialog
  - Re-enabling the initial code for setting the starting directory
    and finish implementation
  - Translation updates
* Sun Nov  3 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 0.6.0
  - UI updated to use GTK+3
  - modernized the code a little in the process
- Various spec file cleanups
* Mon Dec 18 2017 seife+obs@b1-systems.com
- update to 0.5.5
  - Use gstreamer discovere api to get track duration
  - Update xfburn icon in desktop-integration and main windows
  - Do not use deprecated media-cdrom Icon (bxo#12233)
  - Add appdata file (bxo#11201)
  - Add GenericName in xfburn.desktop.in (bxo#12170)
  - Do no open data-composition when running --audio-composition
    (bxo#13251)
  - Improve error message when a plugin is missing.
  - Missing strings in translations (bxo#11291)
  - Translation Updates
* Sun May 17 2015 gber@opensuse.org
- update to version 0.5.4
  - some autoconf modernization
  - use gstreamer 1.0 api
  - restore broken icons
* Thu Apr 10 2014 gber@opensuse.org
- update to version 0.5.2
  - Blu-Ray support
  - Large file support (iso9660 level 3)
  - Small bugfixes
* Thu Feb 20 2014 gber@opensuse.org
- update to version 0.5.0
  - Updates to the underlying libraries (use gio, libxfce4ui), new
    icon, remove the file browser by default, and many smaller
    bugfixes
- drop obsolete xfburn-fix-missing-include.patch
* Sat Apr 14 2012 gber@opensuse.org
- added xfburn-fix-missing-include.patch in order to include a
  missing header
* Sun Apr  1 2012 gber@opensuse.org
- specfile cleanup
- correct dependencies
- drop xfburn-0.4.3-desktop.patch and edit files in place
- split off -lang subpackage
* Thu Feb 17 2011 gber@opensuse.org
- call %%desktop_database_post/un
- call %%icon_theme_cache_post/un
* Sun Dec 26 2010 gber@opensuse.org
- corrected license
- updated xfburn-0.4.3-desktop.patch in order to fix desktop files
- remove unsupported locales
- enabled GStreamer support
* Wed Dec 15 2010 prusnak@opensuse.org
- add thunar to Requires
* Thu Feb 25 2010 prusnak@suse.cz
- updated to 0.4.3
  - Fall back gracefully to use libburn when compiled with HAL support but
    when the HAL daemon is not running.
  - Again show the volume name in the burn dialog if it has the default value
  - By default let libburn autodetect the write mode
  - Fix a crash after burning is complete
  - Fix a crash when adding files to a composition which was non-empty
  - Don't ask unlimited number of times if a disc should get blanked
  - Always check for mounted discs before using the drive
* Wed Aug 12 2009 prusnak@suse.cz
- updated to 0.4.2
  - Internal updates in preparation for better handling of disc detection
  - Handle drag and drop of filenames with spaces from thunar (closes #4992)
  - Insert dragged file dropped on top of another file instead of crashing
    (closes #5299)
  - Properly detect the available space on an audio CD (closes #5302)
  - Track ownership of tracks in compositions correctly (closes #5303)
  - Resample audio files with gstreamer if necessary (closes #5304)
  - Show symbolic links in the file browser (closes #5430)
  - Implement the "show hidden files" option (closes #5500)
* Wed Feb 25 2009 prusnak@suse.cz
- updated to 0.4.1
  * When thunar-vfs is not present, Completely disable drag and drop from
    Thunar (and other file managers). Otherwise gtk complains (and potentially
    causes errors).
  * Adding directories to a composition from within xfburn works again.
  * Bump libburn version requirement to 0.5.6, since earlier versions might
    trigger a crash in libburn's fifo code. Version 0.4.2 or later will work,
    aside from this problem.
  * Correctly detect some burners for which HAL reported unexpected values.
  * Fall back to libburn-based burner detection if HAL does not find any.
  * A man page is now included.
* Tue Feb 17 2009 prusnak@suse.cz
- updated to 0.4.0
  * Display an error if gstreamer realizes a plugin is missing to decode a file
  * Jean-François Wauthy officially retired as maintainer. Thank you for all the
    work, p0llux!
  * Add symlink as symlink, and not the referenced files to a data composition
  * Allow adding hidden files and devices to the composition through the
    command line (they are not shown in the file selector)
  * Add an entry to Thunar's sendto menu for adding to a data composition
    (thanks Mike Massonnet)
  * Add directories to a data composition with the correct timestamp
    (thanks JR Oldroyd for discovering this)
  * Stop button works now
  * Drag and drop into an audio composition now adds files in the correct order
  * Check that the size of the burn run actually fits on the inserted disc
  * Internal and string improvements
  * Use gstreamer to decompress any supported audio files to burn an audio CD ("gst" transcoder)
  * Burn audio CDs from uncompressed CD audio .wav files ("basic" transcoder)
  * Allow drags and drop from file managers like Thunar (text/uri-list target)
  * Require HAL if compiled with HAL support
  * Try to unmount a drive if it is not accessible (requires thunar-vfs)
  * Build list of drives initially from HAL, then fill in details using libburn
    once the burn dialog shows up
* Mon Jul 21 2008 prusnak@suse.cz
- updated to 0.3.2
  * use libburnia libraries
* Tue Dec  4 2007 prusnak@suse.cz
- use %%find_lang macro
* Tue Mar 13 2007 prusnak@suse.cz
- initial version 0.2.0
